@@ -35,9 +35,11 @@ static const struct pci_device {
 	uint16_t gen;
 } pciids[] = {
 	/* Keep ids sorted by gen; latest gen first */
+	INTEL_ADLS_IDS(12),
 	INTEL_RKL_IDS(12),
 	INTEL_DG1_IDS(12),
 	INTEL_TGL_12_IDS(12),
+	INTEL_JSL_IDS(11),
 	INTEL_EHL_IDS(11),
 	INTEL_ICL_11_IDS(11),
 	INTEL_CNL_IDS(10),
